#!/bin/bash

if [ ! $(command -v docker) ]; then
	echo -e "\t 请先安装docker环境"
	exit 1
fi
if [ $(command -v docker-compose) ]; then
	DC_CMD="docker-compose"
else
	DC_CMD="docker compose"
fi
if [ ! -d "uuwaf" ]; then
	SCRIPT_PATH="$( cd "$( dirname "${BASH_SOURCE[0]}" )" && pwd )"
	cd  "$SCRIPT_PATH"
fi

install_uuwaf(){
	docker network create --driver bridge --subnet 172.22.0.0/24 --gateway 172.22.0.1 wafnet
	$DC_CMD build
}

uninstall_uuwaf(){
	$DC_CMD down > /dev/null 2>&1
	docker rm uuwaf waf-db > /dev/null 2>&1
	docker volume rm waf-community_db-data
	docker rmi waf-community_uuwaf percona:8 -f
	docker network rm wafnet
}

start_uuwaf(){
	if [ $(command -v netstat) ]; then
		port_status=`netstat -nlt|grep -E ':(80|443|777|4443)\s'|wc -l`
		if [ $port_status -gt 0 ]; then
			echo -e "\t 端口80、443、777、4443中的一个或多个被占用，请关闭对应服务或修改其端口"
			exit 1
		fi
	fi
	$DC_CMD up -d
}

stop_uuwaf(){
	$DC_CMD down
}

start_menu(){
    clear
    echo "========================="
    echo "南墙Docker管理"
    echo "========================="
    echo "1. 安装"
    echo "2. 卸载"
    echo "3. 启动"
    echo "4. 停止"
    echo "5. 退出"
    echo
    read -p "请输入数字:" num
    case "$num" in
    	1)
	install_uuwaf
	;;
	2)
	uninstall_uuwaf
	;;
    	3)
	start_uuwaf
	;;
	4)
	stop_uuwaf
	;;
	5)
	exit 1
	;;
	*)
	clear
	echo "请输入正确数字"
	sleep 5s
	start_menu
	;;
    esac
}

start_menu
